@@ -2,4 +2,4 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from ssht00ls.v1 import *
\ No newline at end of file
+from ssht00ls.classes import *
\ No newline at end of file
