@@ -35,9 +35,9 @@ try:
 except ImportError as e:
 	import os
 	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {syst3m.defaults.get_source_path(__file__, back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
+		os.system(f"/usr/bin/pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
 	else:
-		os.system(f"pip3 install -r {syst3m.defaults.get_source_path(__file__, back=3)}/requirements/requirements.txt")
+		os.system(f"pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.txt")
 
 	# imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, pexpect, random, getpass, time
@@ -49,10 +49,10 @@ except ImportError as e:
 
 
 # source.	
-SOURCE_PATH = syst3m.defaults.get_source_path(__file__, back=3)
-BASE = syst3m.defaults.get_source_path(SOURCE_PATH)
-OS = syst3m.defaults.check_operating_system(supported=["linux", "osx"])
-syst3m.defaults.check_alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
+SOURCE_PATH = syst3m.defaults.source_path(__file__, back=3)
+BASE = syst3m.defaults.source_path(SOURCE_PATH)
+OS = syst3m.defaults.operating_system(supported=["linux", "osx"])
+syst3m.defaults.alias(alias=ALIAS, executable=f"{SOURCE_PATH}")
 
 # universal variables.
 USER = OWNER = os.environ.get("USER")
