@@ -150,24 +150,19 @@ class SSync(object):
 					return r3sponse.error_response(f"Path [{path}] is not a directory.")
 
 			# index.
-			index, gfp, ids = Files.Dictionary(path=False, dictionary={}), Formats.FilePath("/"), []
-			for _path_ in Files.Directory(path=path).paths(recursive=True):
+			index, gfp, dir, ids = Files.Dictionary(path=False, dictionary={}), Formats.FilePath("/"), Files.Directory(path=path), []
+			for _path_ in dir.paths(recursive=True, files_only=True):
 				fp = Formats.FilePath(_path_)
 				if fp.name() not in [".DS_Store"] and fp.basename() not in ["__pycache__"]:
 					id = _path_
-					if fp.directory(): id += " (d)"
+					if fp.directory(): 
+						id += " (d)"
+						if os.listdir(_path_) == []: id += " (e)"
 					if id not in ids: ids.append(id)
 					index[id] = fp.mtime(format="seconds")
-			def get_dirs(path):
-				dirs = []
-				for _, _dirs_, _ in os.walk(path):
-					for dir in _dirs_: 
-						newpath = gfp.clean(path=f"{path}/{dir}/")
-						dirs.append(newpath)
-						dirs += get_dirs(newpath)
-				return dirs
-			for _path_ in get_dirs(path):
+			for _path_ in dir.paths(recursive=True, dirs_only=True):
 				id = _path_+" (d)"
+				if os.listdir(_path_) == []: id += " (e)"
 				if id not in ids: 
 					index[id] = gfp.mtime(path=_path_, format="seconds")
 					ids.append(id)
@@ -191,6 +186,7 @@ class SSync(object):
 		exclude=None,
 		# path is directory boolean (leave None to parse automatically).
 		directory=None,
+		empty_directory=False,
 		# update deleted files.
 		delete=False,
 		# forced mode.
@@ -251,6 +247,10 @@ class SSync(object):
 			if log_level >= 3:
 				print(f"Created directory {base}.")
 
+		# fix rsync timestamp bug.
+		if empty_directory and directory and not os.path.exists(path):
+			os.system(f"mkdir -p {path}")
+
 		# pull.
 		if exclude == None: exclude = self.exclude
 		exclude_str = ""
@@ -283,6 +283,7 @@ class SSync(object):
 		exclude=None,
 		# path is directory boolean (leave None to parse automatically).
 		directory=None,
+		empty_directory=False,
 		# update deleted files.
 		delete=False,
 		# forced mode.
@@ -552,8 +553,9 @@ class SSync(object):
 			for subpath, info in mismatches.items():
 
 				# vars.
-				directory = " (d)" in subpath
-				subpath = subpath.split(" (d)")[0]
+				directory = info["directory"]
+				empty_directory = info["empty_directory"]
+				subpath = subpath.split(" (d)")[0] # just to be sure.
 				lfullpath, rfullpath = self.fullpath(subpath), self.fullpath(subpath, remote=True)
 				try: lmtime = index[subpath]
 				except KeyError: lmtime = None
@@ -644,7 +646,8 @@ class SSync(object):
 						"options":options,
 						"remote_to_local":remote_to_local,
 						"local_to_remote":local_to_remote,
-						"directory":directory,}
+						"directory":directory,
+						"empty_directory":empty_directory,}
 				elif remote_to_local or local_to_remote:
 					if self.log_level >= 1: 
 						if local_to_remote:
@@ -655,7 +658,8 @@ class SSync(object):
 						"options":options,
 						"remote_to_local":remote_to_local,
 						"local_to_remote":local_to_remote,
-						"directory":directory,}
+						"directory":directory,
+						"empty_directory":empty_directory,}
 			# handler.
 			self.set_last_index(index) ; self.set_last_index(remote_index, remote=True)
 			return r3sponse.success_response(f"Successfully indexed [{self.alias}:{rfullpath}] & [{lfullpath}].", {
@@ -665,26 +669,28 @@ class SSync(object):
 				"index":index,
 				"remote_index":remote_index,
 			})
-		def local_to_remote(self, path, info, directory=False, forced=False, delete=False):
+		def local_to_remote(self, path, info, directory=False, empty_directory=False, forced=False, delete=False):
 			if self.log_level >= 0: print(f"Synchronizing {path} to {self.alias}:{path} (delete: {delete}) (forced: {forced}).")
 			return self.ssync.push(
 				path=self.fullpath(path, append_slash=directory), 
 				alias=self.alias, 
 				remote=self.fullpath(path, remote=True, append_slash=directory), 
 				directory=directory,
+				empty_directory=empty_directory,
 				delete=delete,
 				forced=forced,
 				safe=False,
 				accept_new_host_keys=True,
 				checks=False,
 				log_level=self.log_level,)
-		def remote_to_local(self, path, info, directory=False, forced=False, delete=False):
+		def remote_to_local(self, path, info, directory=False, empty_directory=False, forced=False, delete=False):
 			if self.log_level >= 0: print(f"Synchronizing {self.alias}:{path} to {path} (delete: {delete}) (forced: {forced}).")
 			return self.ssync.pull(
 				path=self.fullpath(path, append_slash=directory), 
 				alias=self.alias, 
 				remote=self.fullpath(path, remote=True, append_slash=directory), 
 				directory=directory,
+				empty_directory=empty_directory,
 				delete=delete,
 				forced=forced,
 				safe=False,
@@ -712,6 +718,8 @@ class SSync(object):
 				if not synchronized: 
 					mismatches[subpath] = {
 						"path":subpath,
+						"directory":" (d)" in fullpath,
+						"empty_directory":" (d)" in fullpath and " (e)" in fullpath,
 						"local_mtime":lmtime,
 						"remote_mtime":rmtime,
 					}
