@@ -17,24 +17,19 @@ elif not os.path.isdir(path):
 	r3sponse.log(response=r3sponse.error_response(f"Path [{path}] is not a directory."), json=json)
 
 # index.
-index, gfp, ids = Files.Dictionary(path=False, dictionary={}), Formats.FilePath("/"), []
-for _path_ in Files.Directory(path=path).paths(recursive=True):
+index, gfp, dir, ids = Files.Dictionary(path=False, dictionary={}), Formats.FilePath("/"), Files.Directory(path=path), []
+for _path_ in dir.paths(recursive=True, files_only=True):
 	fp = Formats.FilePath(_path_)
 	if fp.name() not in [".DS_Store"] and fp.basename() not in ["__pycache__"]:
 		id = _path_
-		if fp.directory(): id += " (d)"
+		if fp.directory(): 
+			id += " (d)"
+			if os.listdir(_path_) == []: id += " (e)"
 		if id not in ids: ids.append(id)
 		index[id] = fp.mtime(format="seconds")
-def get_dirs(path):
-	dirs = []
-	for _, _dirs_, _ in os.walk(path):
-		for dir in _dirs_: 
-			newpath = gfp.clean(path=f"{path}/{dir}/")
-			dirs.append(newpath)
-			dirs += get_dirs(newpath)
-	return dirs
-for _path_ in get_dirs(path):
+for _path_ in dir.paths(recursive=True, dirs_only=True):
 	id = _path_+" (d)"
+	if os.listdir(_path_) == []: id += " (e)"
 	if id not in ids: 
 		index[id] = gfp.mtime(path=_path_, format="seconds")
 		ids.append(id)
